@@ -2,8 +2,8 @@ package govarnam
 
 import (
 	"context"
-	"io/ioutil"
 	"log"
+	"os"
 	"path"
 	"strings"
 	"testing"
@@ -195,6 +195,26 @@ func TestMLTrain(t *testing.T) {
 	assertEqual(t, err.Error(), "nothing to unlearn")
 }
 
+func TestAnyCharacterInputWillWorkFine(t *testing.T) {
+	// After working with Ruby on Rails for a while,
+	// I got the habit of describing method names elaborately
+	varnam := getVarnamInstance("ml")
+
+	varnam.Learn("ഒന്നും", 0)
+	varnam.Learn("പകൽ", 0)
+	assertEqual(
+		t,
+		varnam.TransliterateAdvanced("onnum!@#$%^&*(പകൽ);'[]?.,`*/kall").DictionarySuggestions[0].Word,
+		"ഒന്നും!@#$%^&*(പകൽ);'[]?.,`*ഽകല്ല്",
+	)
+
+	assertEqual(
+		t,
+		varnam.Transliterate("1-bi yil paTTikkunna kutti?!")[0].Word,
+		"1-ബി യിൽ പഠിക്കുന്ന കുട്ടി?!",
+	)
+}
+
 // TestML zero width joiner/non-joiner things
 func TestMLZW(t *testing.T) {
 	varnam := getVarnamInstance("ml")
@@ -357,7 +377,7 @@ func TestMLExportAndImport(t *testing.T) {
 	varnam.Export(exportFileIntendedPath, 300)
 
 	// read the whole file at once
-	b, err := ioutil.ReadFile(exportFilePath)
+	b, err := os.ReadFile(exportFilePath)
 	if err != nil {
 		panic(err)
 	}
@@ -458,6 +478,7 @@ func TestMLRecentlyLearnedWords(t *testing.T) {
 	}
 
 	result, err = varnam.GetRecentlyLearntWords(context.Background(), 4, len(words))
+	checkError(err)
 	assertEqual(t, result[0].Word, "ആലപ്പുഴ")
 }
 
@@ -475,3 +496,16 @@ func TestMLGetSuggestions(t *testing.T) {
 
 	assertEqual(t, result[0].Word, "ആലപ്പുഴ")
 }
+
+func TestMLNativePartialWordsInInput(t *testing.T) {
+	varnam := getVarnamInstance("ml")
+
+	words := []string{"ആലപ്പുഴ", "പുസ്തകം"}
+	for _, word := range words {
+		varnam.Learn(word, 0)
+	}
+
+	assertEqual(t, varnam.TransliterateAdvanced("ആലppu").DictionarySuggestions[0].Word, "ആലപ്പുഴ")
+	assertEqual(t, varnam.TransliterateAdvanced("puസ്ത").DictionarySuggestions[0].Word, "പുസ്തകം")
+	assertEqual(t, varnam.TransliterateAdvanced("ആലippazham").DictionarySuggestions[0].Word, "ആലിപ്പഴം")
+}
